@@ -21,7 +21,7 @@ from azure.storage.blob.aio._list_blobs_helper import BlobPrefix
 from azure.storage.blob._models import BlobBlock, BlobProperties, BlobType
 from fsspec import AbstractFileSystem
 from fsspec.asyn import (
-    maybe_sync,
+    sync,
     AsyncFileSystem,
     get_loop,
     sync_wrapper,
@@ -408,7 +408,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         else:
             self.sync_credential = None
         self.do_connect()
-        weakref.finalize(self, maybe_sync, close_service_client, self, self)
+        weakref.finalize(self, sync, self.loop, close_service_client, self)
 
     @classmethod
     def _strip_protocol(cls, path: str):
@@ -545,7 +545,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         except Exception:
             fetch_from_azure = True
         if fetch_from_azure:
-            return maybe_sync(self._info, self, path, refresh)
+            return sync(self.loop, self._info, path, refresh)
         return super().info(path)
 
     async def _info(self, path, refresh=False, **kwargs):
@@ -585,7 +585,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
             raise FileNotFoundError
 
     def glob(self, path, **kwargs):
-        return maybe_sync(self._glob, self, path)
+        return sync(self.loop, self._glob, path)
 
     async def _glob(self, path, **kwargs):
         """
@@ -672,9 +672,9 @@ class AzureBlobFileSystem(AsyncFileSystem):
         **kwargs,
     ):
 
-        files = maybe_sync(
+        files = sync(
+            self.loop,
             self._ls,
-            self,
             path=path,
             invalidate_cache=invalidate_cache,
             delimiter=delimiter,
@@ -870,8 +870,8 @@ class AzureBlobFileSystem(AsyncFileSystem):
         return output
 
     def find(self, path, withdirs=False, prefix="", **kwargs):
-        return maybe_sync(
-            self._find, self, path=path, withdirs=withdirs, prefix=prefix, **kwargs
+        return sync(
+            self.loop, self._find, path=path, withdirs=withdirs, prefix=prefix, **kwargs
         )
 
     async def _find(self, path, withdirs=False, prefix="", with_parent=False, **kwargs):
@@ -1167,7 +1167,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
                 async with self.service_client.get_container_client(
                     container=container_name
                 ) as cc:
-                    await cc.delete_blob(path)
+                    await cc.delete_blob(path.rstrip(delimiter))
             elif kind == "directory":
                 await self._rmdir(container_name)
             else:
@@ -1184,7 +1184,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
     sync_wrapper(_rm_file)
 
     def rmdir(self, path: str, delimiter="/", **kwargs):
-        maybe_sync(self._rmdir, self, path, delimiter=delimiter, **kwargs)
+        sync(self.loop, self._rmdir, path, delimiter=delimiter, **kwargs)
 
     async def _rmdir(self, path: str, delimiter="/", **kwargs):
         """
@@ -1209,7 +1209,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
             self.invalidate_cache(self._parent(path))
 
     def size(self, path):
-        return maybe_sync(self._size, self, path)
+        return sync(self.loop, self._size, path)
 
     async def _size(self, path):
         """Size in bytes of file"""
@@ -1218,7 +1218,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         return size
 
     def isfile(self, path):
-        return maybe_sync(self._isfile, self, path)
+        return sync(self.loop, self._isfile, path)
 
     async def _isfile(self, path):
         """Is this entry file-like?"""
@@ -1238,7 +1238,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
             return False
 
     def isdir(self, path):
-        return maybe_sync(self._isdir, self, path)
+        return sync(self.loop, self._isdir, path)
 
     async def _isdir(self, path):
         """Is this entry directory-like?"""
@@ -1256,7 +1256,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
             return False
 
     def exists(self, path):
-        return maybe_sync(self._exists, self, path)
+        return sync(self.loop, self._exists, path)
 
     async def _exists(self, path):
         """Is there a file at the given path"""
@@ -1323,7 +1323,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
             return self.cat_file(paths[0])
 
     def url(self, path, expires=3600, **kwargs):
-        return maybe_sync(self._url, self, path, expires, **kwargs)
+        return sync(self.loop, self._url, path, expires, **kwargs)
 
     async def _url(self, path, expires=3600, **kwargs):
         """Generate presigned URL to access path by HTTP
@@ -1351,7 +1351,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         return url
 
     def expand_path(self, path, recursive=False, maxdepth=None):
-        return maybe_sync(self._expand_path, self, path, recursive, maxdepth)
+        return sync(self.loop, self._expand_path, path, recursive, maxdepth)
 
     async def _expand_path(self, path, recursive=False, maxdepth=None, **kwargs):
         """Turn one or more globs or directories into a list of all matching files"""
@@ -1472,7 +1472,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
                 os.makedirs(lpath, exist_ok=True)
             else:
                 async with self.service_client.get_blob_client(
-                    container_name, path
+                    container_name, path.rstrip(delimiter)
                 ) as bc:
                     with open(lpath, "wb") as my_blob:
                         stream = await bc.download_blob()
@@ -1647,8 +1647,8 @@ class AzureBlobFile(AbstractBufferedFile):
             self.cache = caches[cache_type](
                 self.blocksize, self._fetch_range, self.size, **cache_options
             )
-            self.metadata = maybe_sync(
-                get_blob_metadata, self, self.container_client, self.blob
+            self.metadata = sync(
+                self.loop, get_blob_metadata, self.container_client, self.blob
             )
 
         else:
